Package: ChileDataAPI
Type: Package
Title: Access Chilean Data via APIs and Curated Datasets
Version: 0.3.0
Maintainer: Renzo Caceres Rossi <arenzocaceresrossi@gmail.com>
Description: Provides functions to access data from public RESTful APIs including
    'FINDIC API', 'World Bank API', and 'Nager.Date', 
    retrieving real-time or historical data related to Chile such as financial indicators, 
    holidays, and more. 
    Additionally, the package includes curated datasets related to Chile, covering topics 
    such as human rights violations during the Pinochet regime, electoral data, census samples, 
    health surveys, seismic events, territorial codes, and environmental measurements. 
    The package supports research and analysis focused on Chile by integrating open APIs with 
    high-quality datasets from multiple domains. For more information on the APIs, see: 
    'FINDIC' <https://findic.cl/>, 
    'World Bank API' <https://datahelpdesk.worldbank.org/knowledgebase/articles/889392>, 
    and 'Nager.Date' <https://date.nager.at/Api>.
License: GPL-3
Language: en
URL: https://github.com/lightbluetitan/chiledataapi,
        https://lightbluetitan.github.io/chiledataapi/
BugReports: https://github.com/lightbluetitan/chiledataapi/issues
Encoding: UTF-8
LazyData: true
Depends: R (>= 4.1.0)
Imports: utils, httr, jsonlite, dplyr, tibble, scales
Suggests: ggplot2, testthat (>= 3.0.0), knitr, rmarkdown
Authors@R: 
    person(
        given = "Renzo",
        family = "Caceres Rossi",
        role = c("aut", "cre"),
        email = "arenzocaceresrossi@gmail.com",
        comment = c(ORCID = "0009-0005-0744-854X")
    )
Config/testthat/edition: 3
VignetteBuilder: knitr
Config/roxygen2/version: 8.0.0
NeedsCompilation: no
Packaged: 2026-07-02 18:43:26 UTC; Renzo
Author: Renzo Caceres Rossi [aut, cre] (ORCID:
    <https://orcid.org/0009-0005-0744-854X>)
Repository: CRAN
Date/Publication: 2026-07-03 03:00:16 UTC
Built: R 4.5.2; ; 2026-07-03 03:16:40 UTC; unix
