# Generated by roxygen2: do not edit by hand

export(census_chile_2017_df)
export(chile_earthquakes_tbl_df)
export(chile_election_2021_df)
export(chile_health_survey_df)
export(chile_plebiscite_df)
export(get_chile_bitcoin)
export(get_chile_child_mortality)
export(get_chile_copper_pound)
export(get_chile_cpi)
export(get_chile_dollar)
export(get_chile_energy_use)
export(get_chile_euro)
export(get_chile_gdp)
export(get_chile_holidays)
export(get_chile_hospital_beds)
export(get_chile_ipsa)
export(get_chile_life_expectancy)
export(get_chile_literacy_rate)
export(get_chile_population)
export(get_chile_uf)
export(get_chile_unemployment)
export(get_chile_utm)
export(get_chile_yen)
export(malleco_tree_rings_ts)
export(pinochet_regime_df)
export(territorial_codes_tbl_df)
export(view_datasets_ChileDataAPI)
importFrom(dplyr,as_tibble)
importFrom(dplyr,mutate)
importFrom(httr,GET)
importFrom(httr,content)
importFrom(httr,status_code)
importFrom(jsonlite,fromJSON)
importFrom(scales,comma)
importFrom(tibble,tibble)
