# ChileDataAPI - Access Chilean Data via APIs and Curated Datasets
# Version 0.3.0
# Copyright (C) 2025-2026 Renzo Caceres Rossi
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.


#' ChileDataAPI: Access Chilean Data via APIs and Curated Datasets
#'
#' \if{html}{\figure{logo.png}{options: style='float: right' alt='logo' width='120'}}
#'
#' Access Chilean Data via APIs and Curated Datasets.
#'
#' @name ChileDataAPI
#' @aliases ChileDataAPI-package
#' @title ChileDataAPI: Access Chilean Data via APIs and Curated Datasets
#' @description {
#' This package provides functions to access data from public RESTful APIs including 'FINDIC API', 'REST Countries API', 'World Bank API', and 'Nager.Date', retrieving real-time or historical data related to Chile such as financial indicators, holidays, international demographic and geopolitical indicators, and more. Additionally, the package includes curated datasets related to Chile, covering topics such as human rights violations during the Pinochet regime, electoral data, census samples, health surveys, seismic events, territorial codes, and environmental measurements..
#' }
#' @seealso {
#' Useful links:
#' \itemize{
#'   \item \url{https://github.com/lightbluetitan/chiledataapi}
#' }
#' }
#' @author {
#' \strong{Maintainer}: Renzo Caceres Rossi \email{arenzocaceresrossi@gmail.com}
#' }
'_PACKAGE'
